##############################################
## PopDensity_Lethal_Robust.R
## Purpose: Robustness Checks
## Date: December 4, 2016
##############################################

rm(list = ls()); gc()

##############################################
## LOADING PREPPED SCAD DATA:
##############################################

setwd(data_dir)
load("SCAD/Prepared_SCAD.Rdata")

# Limiting to events with repression:
scad_dt <- scad_dt[any_repress == 1]

##############################################
## PRIMARY MODELS:
##############################################

m1 <- felm(lethal_repress ~ ln_popdens |
    ccode + eyr | 0 | ccode,
    data = scad_dt)
summary(m1)

##############################################
## CONDITION ON URBAN:
##############################################

m_city <- felm(lethal_repress ~ ln_popdens |
    ccode + eyr + urban | 0 | ccode,
    data = scad_dt)
summary(m_city)
#             Estimate Cluster s.e. t value Pr(>|t|)
# ln_popdens -0.015315     0.006172  -2.481   0.0132 *

m_city_only <- felm(lethal_repress ~ ln_popdens |
    ccode + eyr | 0 | ccode,
    data = scad_dt[urban == 1])
summary(m_city_only)

##############################################
## IDENTIFYING ACTORS:
##############################################

actor_dt <- rbind(scad_dt[!is.na(actor1), .(actor1)], scad_dt[!is.na(actor2), .(actor2)], scad_dt[!is.na(actor3), .(actor3)], use.names = FALSE)
# actor_dt[, .N, by = actor1][order(-N), .(actor1)] %>% as.data.frame()

##############################################
## DROP CASES INVOLVING REBELS
##############################################

reb_str <- c("REBEL", "MILITANT", "GANG", "SUICIDE BOMBING", "ISLAMISTS", "CONGO LIBERATION MOVEMENT", "GOVERNMENT (ALLIANCE OF DEMOCRATIC FORCES FOR THE LIBERATION OF CONGO-ZAIRE)", "ISLAMIC RADICALS", "MOVEMENT FOR THE ACTUALISATION OF THE SOVEREIGN STATE OF BIAFRA", "MOVEMENT FOR THE EMANCIPATION OF THE NIGER DELTA", "CIVIL WAR FIGHTERS", "AL-SHEBAB$", "AL-SHABAB$", "M23", "AL QAEDA", "AL-QAEDA", "FRONT FOR THE RESTORATION AND DEFENSE OF DEMOCRACY", "LORD'S RESISTANCE ARMY", "NIGER DELTA VIGILANTE MOVEMENT", "GUERRILLAS", "INSURGENTS", "\\BMILITIA", "SEPARATISTS", "ARMED BANDITS", "AL-JIHAD", "RENAMO FIGHTERS", "ANSAR DINE", "NUER WHITE ARMY")
reb_expr <- paste(reb_str, collapse = "|")

scad_dt[, rebel := 0L]
scad_dt[grepl(reb_expr, target1, ignore.case = TRUE) |
    grepl(reb_expr, target2, ignore.case = TRUE) |
    grepl(reb_expr, actor1, ignore.case = TRUE) |
    grepl(reb_expr, actor2, ignore.case = TRUE) |
    grepl(reb_expr, actor3, ignore.case = TRUE),
    rebel := 1L]

scad_dt[, .N, by= rebel]
#    rebel    N
# 1:     0 1985
# 2:     1  109

m2 <- felm(lethal_repress ~ ln_popdens |
    ccode + eyr | 0 | ccode,
    data = scad_dt[rebel == 0])
summary(m2)
#             Estimate Cluster s.e. t value Pr(>|t|)
# ln_popdens -0.031225     0.006521  -4.789 1.83e-06 ***

##############################################
## CASES INVOLVING MILITARY:
##############################################

mil_str <- c("SOLDIERS", "ARMED FORCES", "TROOPS", "\\BMILITARY", "SECURITY FORCES", "BARRACKS", "^ARMY")
mil_expr <- paste(mil_str, collapse = "|")

scad_dt[, military := 0L]
scad_dt[grepl(mil_expr, target1, ignore.case = TRUE) |
        grepl(mil_expr, target2, ignore.case = TRUE) |
        grepl(mil_expr, actor1, ignore.case = TRUE) |
        grepl(mil_expr, actor2, ignore.case = TRUE) |
        grepl(mil_expr, actor3, ignore.case = TRUE),
        military := 1L]

# scad_dt[, .N, by= military]
#    military    N
# 1:        0 2019
# 2:        1   75

m3 <- felm(lethal_repress ~ ln_popdens |
    ccode + eyr | 0 | ccode,
    data = scad_dt[military == 0])
summary(m3)
#             Estimate Cluster s.e. t value Pr(>|t|)
# ln_popdens -0.030794     0.005031  -6.121 1.15e-09 ***

##############################################
## DROP CAPITAL CITIES ENTIRELY:
##############################################

m4 <- felm(lethal_repress ~ ln_popdens |
    ccode + eyr | 0 | ccode,
    data = scad_dt[locnum != 1])
summary(m4)
#             Estimate Cluster s.e. t value Pr(>|t|)
# ln_popdens -0.015666     0.007461    -2.1    0.036 *

##############################################
## STUDENTS ONLY:
##############################################

student_expr <- "student|university|youth|teacher"

scad_dt[, student := 0L]
scad_dt[grepl(student_expr, target1, ignore.case = TRUE) |
        grepl(student_expr, target2, ignore.case = TRUE) |
        grepl(student_expr, actor1, ignore.case = TRUE) |
        grepl(student_expr, actor2, ignore.case = TRUE) |
        grepl(student_expr, actor3, ignore.case = TRUE),
        student := 1L]

# scad_dt[, .N, by = student]
#    student    N
# 1:       0 1661
# 2:       1  433

m5 <- felm(lethal_repress ~ ln_popdens |
    ccode + eyr | 0 | ccode,
    data = scad_dt[student == 1])
summary(m5)
#            Estimate Cluster s.e. t value Pr(>|t|)
# ln_popdens -0.04460      0.01824  -2.445   0.0151 *

##############################################
## STUDENTS & CITIZENS:
##############################################

citizen_expr <- "citizen|civilian|women"

scad_dt[, citizen := 0L]
scad_dt[grepl(citizen_expr, target1, ignore.case = TRUE) |
        grepl(citizen_expr, target2, ignore.case = TRUE) |
        grepl(citizen_expr, actor1, ignore.case = TRUE) |
        grepl(citizen_expr, actor2, ignore.case = TRUE) |
        grepl(citizen_expr, actor3, ignore.case = TRUE),
        citizen := 1L]

# scad_dt[, .N, by = citizen][order(citizen)]
#    citizen    N
# 1:       0 1531
# 2:       1  563

m6 <- felm(lethal_repress ~ ln_popdens |
    ccode + eyr | 0 | ccode,
    data = scad_dt[citizen == 1])
summary(m6)
#            Estimate Cluster s.e. t value Pr(>|t|)
# ln_popdens -0.03388      0.01222  -2.774  0.00579 **

##############################################
## COUNTS:
##############################################

m1_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr),
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)))]

m2_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) & rebel == 0,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)))]

m3_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) & military == 0,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)))]

m4_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) & locnum != 1,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)))]

m5_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) & student == 1,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)))]

m6_ct <- scad_dt[!is.na(lethal_repress) & !is.na(ln_popdens) &
    !is.na(ccode) & !is.na(eyr) & citizen == 1,
    list(nyear = length(unique(eyr)),
    ncntry = length(unique(ccode)))]

ct_dt <- rbindlist(list(m1_ct, m2_ct, m3_ct, m4_ct, m5_ct, m6_ct))

# Covariate Labels
covars <- c("Log(Pop. Density)")

# Model Labels:
m_labs <- c("1", "No Rebel", "No Military", "No Capitals", "Students", "Citizens")

# Counts for bottom of table:
cntry_FE <- c("Country FEs", format(ct_dt[, ncntry],
    big.mark = ",", trim = TRUE))
year_FE <- c("Year FEs", format(ct_dt[, nyear], big.mark = ",", trim = TRUE))


add_lines <- list(year_FE, cntry_FE)
add_lines <- lapply(add_lines, function(x) {x[x == "NA"] <- ""; x})

##############################################
## TABLE 16:
##############################################

setwd(tabs_dir)
stargazer(list(m1, m2, m3, m4, m5, m6),
    dep.var.labels = c("$\\mathbb{1}$(Lethal Repression)"),
    covariate.labels = covars,
    column.labels = m_labs,
    model.numbers = FALSE,
    keep.stat = "n",
    p.auto = TRUE,
    star.cutoffs = c(.1, .05),
    star.char = c("\\dagger", "*"),
    add.lines = add_lines,
    notes = "Robust std. errors clustered on country; $^{\\dagger} p <$ 0.1, $^*p <$ 0.05",
    notes.append = FALSE,
    table.placement = "ht!",
    digits = 3,
    label = "tab:popdensity_lethal_robust",
    title = "Addressing Concerns about Variation in Identities of Protesters and Repressers",
    out = "Alt_Identities.tex")


