##############################################
## _Master.R
############################################## 

.env <- new.env()
# Set path to replication directory:
.env$top_dir <- # "~/Dropbox/Geography_Repression/Replication/"

##############################################
## R PACKAGES:
##############################################

pkgs <- c("beepr", "dplyr", "rgdal", "raster", "data.table", "stargazer", "readr", "countrycode", "pBrackets", "lfe", "zoo", "stringr", "lubridate", "ggplot2", "foreign")

sapply(pkgs, require, 
    character.only = TRUE, 
    quietly = TRUE, 
    warn.conflicts = FALSE)

##############################################
## DIRECTORIES
############################################## 

.env$"%nin%" <- function(x, y) !(x %in% y)

# Setting other directories:
.env$code_dir <- paste0(.env$top_dir, "Code/")
.env$data_dir <- paste0(.env$top_dir, "Data/")
.env$figs_dir <- paste0(.env$top_dir, "Figures/")
.env$tabs_dir <- paste0(.env$top_dir, "Tables/")
attach(.env, warn.conflicts = FALSE)

# Loading graphing options:
setwd(code_dir)
source("map_theme.R")
attach(.env, warn.conflicts = FALSE)

##############################################
# Replication Code Files:

# NOTE 1: See PrepSCAD.R for all merges/modifications to the original SCAD data.
# NOTE 2: The LandScan data is proprietary and, thus, cannot be included in the replication archive. As a consequence,  PrepSCAD.R will not run unless you have downloaded the LandScan data to the Replication/Data folder. 

# Table 1: Patterns of Repression across Urban and Rural Protests
# Figure 1: Patterns of Repression Across Countries
setwd(code_dir)
source("1_PrRepression.R")

# Figure 2: Pr(Repression) by Number of Participants
# Table 2: Pr(Repression) by Protest Size and Population Density
# Table 3: Summary Statistics: Pr(Repression) by Protest Size and Population Density
setwd(code_dir)
source("2_PopDensity_Repression.R")

# Table 4: Pr(Lethal Repression) by Population Density
# Table 5: Summary Statistics: Pr(Lethal) by Population Density
setwd(code_dir)
source("3_PopDensity_Lethal.R")

# Table 6: Pr(Multiple News Sources) Given Repression and Location
# Table 7: Pr(Multiple Sources) by Lethal Repression and Location
setwd(code_dir)
source("4a_Alt_ReportingBias.R")

# Table 8: Pr(Lethal Repression) by Distance to Reporting Resources
# Table 9: Summary Statistics: Pr(Lethal) by Distance to Reporting Resource
# WARNING: This script can take a long time to run.
setwd(code_dir)
source("4b_Alt_ReportingBias.R")

# Table 10: International Aid and Repression
# Table 11: Summary Statistics: International Aid
setwd(code_dir)
source("5_Alt_IntlAid.R")

# Table 12: Pr(Lethal Repression) Given History of Armed Conflict
# Table 13: Summary Statistics: Pr(Lethal) Given History of Armed Conflict
# WARNING: This script can take a long time to run.
setwd(code_dir)
source("6_Alt_ArmedConf.R")

# Table 14: Pr(Repression) or Pr(Lethal) Given Proximity to Natural Resources
# Table 15: Summary Statistics: Pr(Repression) or Pr(Lethal) Given Proximity to Natural Resources
# WARNING: This script can take a long time to run.
setwd(code_dir)
source("7_Alt_NatlResources.R")

# Table 16: Addressing Concerns about Variation in Identities of Protesters and Repressers
setwd(code_dir)
source("8_Alt_Identities.R")
